#[non_exhaustive]pub enum FinalizeError {
WriteTransactionRequired,
NotFound,
StateConflict {
row_id: RowId,
},
InvalidTimestamp {
source: ValidationError,
},
MigrationMismatch {
detail: String,
},
Serialization {
detail: String,
},
BusyExhausted {
operation: &'static str,
source: Error,
},
Sql {
operation: &'static str,
source: Error,
},
}Expand description
Errors returned by the migration-only delivery finalizer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WriteTransactionRequired
The transaction was not opened with SQLite’s writer lock.
NotFound
No event row exists for the requested delivery.
StateConflict
The row is not a canonical imported pending delivery.
InvalidTimestamp
Authoritative delivery time failed Dovecote validation.
Fields

source: ValidationErrorOriginal validation error.
MigrationMismatch
Installed durable schema is incompatible with this adapter.
Serialization
Stored or returned data could not be represented safely.
BusyExhausted
A caller transaction remained blocked after the configured busy wait.
Fields
Sql
A non-busy SQLx operation failed.