#[non_exhaustive]pub enum ImportError {
WriteTransactionRequired,
IdentityConflict {
existing_row_id: RowId,
},
ImportConflict {
existing_row_id: RowId,
},
Configuration {
detail: String,
},
InvalidState {
source: ValidationError,
},
MigrationMismatch {
detail: String,
},
Serialization {
detail: String,
},
BusyExhausted {
operation: &'static str,
source: Error,
},
Sql {
operation: &'static str,
source: Error,
},
}Expand description
Errors returned by the migration-only importer.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WriteTransactionRequired
The transaction was not opened with SQLite’s writer lock.
IdentityConflict
Existing identity has different immutable event content.
ImportConflict
Existing delivery state differs from the requested imported state.
Configuration
The adapter configuration is not valid for SQLite.
InvalidState
Imported state failed Dovecote validation.
Fields

source: ValidationErrorOriginal validation error.
MigrationMismatch
Installed durable schema is incompatible with this adapter.
Serialization
Stored or returned data could not be represented safely.
BusyExhausted
A caller transaction remained blocked after the configured busy wait.
Fields
Sql
A non-busy SQLx operation failed.