#[non_exhaustive]pub enum MutationError {
NotFound,
IllegalTransition {
state: DeliveryState,
},
LostClaim,
MigrationMismatch {
detail: String,
},
Configuration {
detail: String,
},
Serialization {
detail: String,
},
BusyExhausted {
operation: &'static str,
source: Error,
},
Sql {
operation: &'static str,
source: Error,
},
}Expand description
Errors returned by claim-token-fenced delivery mutations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NotFound
No event row exists for the requested delivery.
IllegalTransition
The requested mutation is invalid for the current delivery state.
Fields

state: DeliveryStateCurrent durable delivery state.
LostClaim
The supplied claim token no longer owns the delivery.
MigrationMismatch
Installed durable schema is incompatible with this adapter.
Configuration
The adapter’s bounded busy policy is not representable by SQLite.
Serialization
Stored or returned data could not be represented safely.
BusyExhausted
A mutation could not finish after the configured busy retries.
Fields
Sql
A non-busy SQLx operation failed.