begin_enqueue

Function begin_enqueue 

pub async fn begin_enqueue(
    pool: &SqlitePool,
) -> Result<Transaction<'static, Sqlite>, EnqueueError>
Alias for begin_write for callers about to enqueue an event.

Errors

Returns an error for invalid busy configuration or if the SQLite writer reservation cannot be acquired within the configured busy budget.