begin_write

Function begin_write 

pub async fn begin_write(
    pool: &SqlitePool,
) -> Result<Transaction<'static, Sqlite>, EnqueueError>
Begins a caller write transaction using the default busy policy. The returned transaction is safe to pass to TenantDovecote::enqueue.

Errors

Returns an error for invalid busy configuration or if the SQLite writer reservation cannot be acquired within the configured busy budget.