pub async fn begin_write(
pool: &SqlitePool,
) -> Result<Transaction<'static, Sqlite>, EnqueueError>Expand description
Begins a caller write transaction using the default busy policy. The
returned transaction is safe to pass to enqueue.
pub async fn begin_write(
pool: &SqlitePool,
) -> Result<Transaction<'static, Sqlite>, EnqueueError>Begins a caller write transaction using the default busy policy. The
returned transaction is safe to pass to enqueue.